@@ -31,14 +31,8 @@ extern PERLIO_FUNCS_DECL(PerlIO_flock);
 extern PERLIO_FUNCS_DECL(PerlIO_creat);
 extern PERLIO_FUNCS_DECL(PerlIO_excl);
 extern PERLIO_FUNCS_DECL(PerlIO_tee);
-
-
-#if defined(Direntry_t) && defined(HAS_READDIR)
 extern PERLIO_FUNCS_DECL(PerlIO_dir);
-#define define_dir_layer() PerlIO_define_layer(aTHX_ PERLIO_FUNCS_CAST(&PerlIO_dir))
-#else
-#define define_dir_layer() NOOP
-#endif
+extern PERLIO_FUNCS_DECL(PerlIO_reverse);
 
 
 #endif /*PERLIO_UTIL_H*/
